function is_connected = check_connectivity(phase_indicator)

% Find the largest connected component of the given phase as a list of
% linear indices for its voxels.
CC = bwconncomp(phase_indicator);
volumes = cellfun(@numel, CC.PixelIdxList);
[~, idx] = max(volumes);
voxel_idx_list = CC.PixelIdxList{idx};

% Verify that this component is connected to both the inlet and the outlet
% planes in all three directions.
number_of_voxels = size(phase_indicator, 1);
[x, y, z] = ind2sub([number_of_voxels, number_of_voxels, number_of_voxels], voxel_idx_list);
if (min(x) == 1) && (max(x) == number_of_voxels) && ...
   (min(y) == 1) && (max(y) == number_of_voxels) && ...
   (min(z) == 1) && (max(z) == number_of_voxels)
    is_connected = true;
else
    is_connected = false;
end

end