function BW = generate_structure(theta, number_of_voxels)

% Extract parameters.
ax = theta(1);
ay = theta(2);
az = theta(3);
epsilon = theta(4);

% Fourier space grid.
[X, Y, Z] = ndgrid( -number_of_voxels/2:number_of_voxels/2-1, ...
                    -number_of_voxels/2:number_of_voxels/2-1, ...
                    -number_of_voxels/2:number_of_voxels/2-1);

% Rescaled white noise.
B = randn(number_of_voxels, number_of_voxels, number_of_voxels);

% Fourier transform of the white noise.
A = fftn(B); 

% Spectral density of the covariance function.
GAMMA = ( 1 + ( (ax * X).^2 + (ay * Y).^2 + (az * Z).^2 ).^4  ).^ (-2);

% Generate GRF from the white noise and covariance function.
A = A .* GAMMA.^(1 / 2);
GRF = ifftn(fftshift(A), 'symmetric');

% Threshold to obtain prescribed porosity.
T = prctile(GRF(:), 100 * epsilon);
BW = GRF >= T;

% Check connectivity of pores and solid.
is_connected_pores = check_connectivity(~BW);
is_connected_solid = check_connectivity(BW);

% Determine whether the generated structure satisfies the conditions.
is_ok = true;
if ~is_connected_pores || ~is_connected_solid
    is_ok = false;
end

% If not ok, return empty structure.
if ~is_ok
    BW = [];
end

end
